v0.0.1
------

- first release of atqo, yay!!- ignore drafts
- initial commit
- expand exchange tests
- articulate
- bump coverage
- add ray reqs
- init readme
- setup docs
- Merge branch 'template'
# Please enter a commit message to explain why this merge is necessary,
# especially if it merges an updated upstream into a topic branch.
#
# Lines starting with '#' will be ignored, and an empty message aborts
# the commit.
- no ray for python 3.10 :(
- into pypi
